#include "stm32f1xx_hal.h"
#include "mxconstants.h"

#include "socket.h"

int wizSystemInit(void);
void W5500HardwareReset(void);
void W5500WriteByte(unsigned char txByte);
unsigned char W5500ReadByte(void);
void W5500Select(void);
void W5500DeSelect(void);
int isLinked(void);
void print_network_information(void);

static uint32_t randomKey;

extern wiz_NetInfo gWIZNETINFO;
extern SPI_HandleTypeDef hspi1;

int wizSystemInit(void)
{
	uint8_t W5500SockBufSize[2][8] = {{2,2,2,2,2,2,2,2,},{2,2,2,2,2,2,2,2}};
	uint32_t tickStart;

	/* spi function register */
	reg_wizchip_spi_cbfunc(W5500ReadByte, W5500WriteByte);

	/* CS function register */
	reg_wizchip_cs_cbfunc(W5500Select, W5500DeSelect);

	///* Critical section */
	//reg_wizchip_cris_cbfunc(spiMutexEnter,spiMutexExit);

	//W5500Select();

	if(ctlwizchip(CW_INIT_WIZCHIP,(void*)W5500SockBufSize) == -1)
	{
		printf("W5500 initialized fail.\r\n");
		return -1;
	}
	/*Set network information by default*/
	wizchip_setnetinfo(&gWIZNETINFO);
	tickStart = HAL_GetTick();
	do{//check phy status.
		randomKey++;
		if((HAL_GetTick() - tickStart) > 3000 )
		{
			printf("Ethernet Link timeout.\r\n");
			return -1;
		}
	}while(!isLinked());
	return 1;
}

void W5500HardwareReset(void)
{
  uint32_t tempTick;
  HAL_GPIO_WritePin(GPIOA ,W5500_RESET_Pin,GPIO_PIN_RESET);
  tempTick = HAL_GetTick();
  while((HAL_GetTick() - tempTick) < 1 ){/*1 ms Delay: Do nothing*/}
  HAL_GPIO_WritePin(W5500_RESET_Port, W5500_RESET_Pin,GPIO_PIN_SET);
}

void W5500WriteByte(unsigned char txByte)
{
  unsigned char rtnByte;
  while (HAL_SPI_GetState(&hspi1) != HAL_SPI_STATE_READY);
  HAL_SPI_TransmitReceive(&hspi1,&txByte,&rtnByte,1,10);
}

unsigned char W5500ReadByte(void)
{
  unsigned char txByte = 0xff;//dummy
  unsigned char rtnByte;
  while (HAL_SPI_GetState(&hspi1) != HAL_SPI_STATE_READY);
  HAL_SPI_TransmitReceive(&hspi1,&txByte,&rtnByte,1,10);
  return rtnByte;
}

void W5500Select(void)
{
  HAL_GPIO_WritePin(SPI1_CS_GPIO_Port, SPI1_CS_Pin, GPIO_PIN_RESET);
}

void W5500DeSelect(void)
{
  HAL_GPIO_WritePin(SPI1_CS_GPIO_Port, SPI1_CS_Pin, GPIO_PIN_SET);
}

int isLinked(void)
{
	return (getPHYCFGR() & PHYCFGR_LNK_ON);
}

void print_network_information(void)
{
	wizchip_getnetinfo(&gWIZNETINFO);
	printf("IP address : %d.%d.%d.%d\n\r",gWIZNETINFO.ip[0],gWIZNETINFO.ip[1],gWIZNETINFO.ip[2],gWIZNETINFO.ip[3]);
	printf("SM Mask	   : %d.%d.%d.%d\n\r",gWIZNETINFO.sn[0],gWIZNETINFO.sn[1],gWIZNETINFO.sn[2],gWIZNETINFO.sn[3]);
	printf("Gate way   : %d.%d.%d.%d\n\r",gWIZNETINFO.gw[0],gWIZNETINFO.gw[1],gWIZNETINFO.gw[2],gWIZNETINFO.gw[3]);
	printf("DNS Server : %d.%d.%d.%d\n\r",gWIZNETINFO.dns[0],gWIZNETINFO.dns[1],gWIZNETINFO.dns[2],gWIZNETINFO.dns[3]);
}